class DspaceUploadWorker
  include Sidekiq::Worker
  include RepositoriesProxy

  @@dspace= nil

  def perform(learning_object_id, item_id, media_path, *options)
    # create file instance
    file = File.new(media_path, 'r')

    #create bitstream in dspace
    bitstream = dspace.items.add_bitstream(file, id: item_id, name: File.basename(media_path), description: get_description(options))

    #find learning object
    learning_object = learning_object_repository.find learning_object_id
    learning_object.attachments << build_attachment(bitstream)

    #build attachments and publish
    publisher.publish! learning_object
  end

  private

  def build_attachment(bitstream)
    ::LearningObject::Attachment.new(id: bitstream.id, name: bitstream.name, link: bitstream.link,
                                     retrieve_link: bitstream.retrieve_link, description: bitstream.description,
                                     format: bitstream.format, mime_type: bitstream.mime_type, size: bitstream.size_bytes, bundle_name: bitstream.bundle_name, uptodate: false)
  end

  def publisher
    @publisher ||= LearningObjectPublisher.new(dspace)
  end

  def dspace
    @@dspace ||= DspaceService.create_client
  end

  def get_description(*options)
    description = nil
    if options.has_key? :description
      description = options[:description]
    end
    description
  end

end
